@@ -1,6 +1,11 @@
-from django.conf.urls import url, patterns
+from django.urls import re_path
 from django.conf import settings
-from models import Redirect
+from robustredirects.models import Redirect
+from robustredirects import views
+
+
+def ignored_url_paths():
+    return getattr(settings, "ROBUST_REDIRECTS_IGNORED_PREFIXES", ())
 
 
 def group_arguments(seq, group=254):
@@ -37,13 +42,13 @@ def get_redirect_patterns():
 
         if redirect.http_status == 302:
             extra.update({'permanent': False})
-            url_list.append(url(pattern, 'redirect_to', extra))
+            url_list.append(re_path(pattern, views.redirect_to, extra))
         else:
-            url_list.append(url(pattern, 'redirect_to', extra))
+            url_list.append(re_path(pattern, views.redirect_to, extra))
 
     arg_groups = list(group_arguments(url_list))
     for args in arg_groups:
-        url_patterns += patterns('robustredirects.views', *args)
+        url_patterns += list(args)
 
     return url_patterns
 
